@@ -154,7 +154,7 @@ charset_combo_box_run_dialog (ECharsetComboBox *combo_box)
 	}
 
 	charset = gtk_entry_get_text (entry);
-	g_return_if_fail (charset != NULL && charset != '\0');
+	g_return_if_fail (charset != NULL && charset[0] != '\0');
 
 	g_object_set_data_full (
 		object, "charset", g_strdup (charset),
@@ -333,7 +333,7 @@ charset_combo_box_init (ECharsetComboBox *combo_box)
 	/* Note the "other" action is not included in the index. */
 
 	radio_action = gtk_radio_action_new (
-		"charset-other", _("Other..."), NULL, NULL, OTHER_VALUE);
+		"charset-other", _("Other…"), NULL, NULL, OTHER_VALUE);
 
 	g_object_set_data (G_OBJECT (radio_action), "charset", (gpointer) "");
 
