@@ -1,14 +1,13 @@
 #ifndef __SCORE_ADD_UI_H__
 #define __SCORE_ADD_UI_H__
 
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkwidget.h>
+#include "gtk-compat.h"
 #include <pan/data/article.h>
 #include <pan/data/data.h>
 
 namespace pan
 {
-  /** 
+  /**
    * Dialog for creating a new entry for the Scorefile.
    * @ingroup GUI
    */
@@ -29,6 +28,7 @@ namespace pan
     private:
       Data& _data;
       const Article _article;
+      Quark _group;
       GtkWidget * _root;
       GtkWidget * _section_menu;
       GtkWidget * _section_entry;
