@@ -13,16 +13,28 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 #ifndef URL_SHOW_H
 #define URL_SHOW_H
 
+#include <set>
+#include <string>
+#include "prefs.h"
+
 namespace pan
 {
-  /** @ingroup GUI */
-  void pan_url_show (const char * url);
+  struct URL
+  {
+    static const char* get_environment ();
+
+    static void get_default_editors (std::set<std::string>& setme);
+
+    enum Mode { WEB, MAIL, AUTO };
+
+    static void open (const Prefs&, const char * url, Mode mode=AUTO);
+  };
 }
 
 #endif
